Package 'labstat'

Title: Statistics for Lab Scientists
Description: Data and code for a course in statistics for laboratory scientists.
Authors: Karl W Broman [aut, cre]
Maintainer: Karl W Broman <[email protected]>
License: GPL-3
Version: 0.11-4
Built: 2026-05-15 11:56:26 UTC
Source: https://github.com/kbroman/labstat

Help Index


Percent visceralization

Description

Percent visceralization in the spleen and liver of mice given four different diets.

Usage

data(anstead)

Format

A data frame with four columns: type of diet, organ, number of mice showing visceralization, and total number of mice.

References

Anstead, G. M., Chandrasekar, B., Zhao, W., Yang, J., Perez, L. E. and Melby, P. C. (2001) Malnutrition alters the inate immune response and increases early visceralization following Leismania donovani infection. Infection and Immunity 69, 4709-4718. (See Figure 1B.)

Examples

data(anstead)
p <- anstead[,3]/anstead[,4]*100
par(las=1)
barplot(p,width=1,space=c(0,0,rep(c(1,0),3)),xlab="Diet",ylab="Percent visceralization",
        ylim=c(0,100),col=c("black","gray"),xlim=c(-0.5,11.5))
abline(h=0)
x <- c(-0.5,2.5,5.5,8.5,11.5)
segments(x,0,x,-2,xpd=TRUE)
x <- c(1,4,7,10)
text(x,-6,c("A","B","C","D"),xpd=TRUE)
legend(0,100,c("Spleen","Liver"),pch=15,cex=1.15,
       col=c("black","gray"))
legend(0,100,c("",""),pch=0,bty="n",cex=1.15)

Amount of viral RNA

Description

Amount of viral RNA in the central nervous systems of mice with three different genotypes at 6, 21 and 45 days after infection with Theiler's virus.

Usage

data(aubagnac)

Format

A data frame with four columns: mouse strain (genotype), days post infection, and amount of viral RNA in spinal cord and brain.

Jean-Francois Bureau, Institut Pasteur, France

References

Aubagnac, S., Brahic, M. and Bureau, J.-F. (2001) Viral load increases in SJL/J mice persistently infected by Theiler's virus after inactivation of the β2m\beta_2m gene. J. Virol. 75, 7723-7726. (See Figure 1.)

Examples

data(aubagnac)
me.s <- tapply(aubagnac[,3],list(aubagnac[,1],aubagnac[,2]),mean,na.rm=TRUE)
me.b <- tapply(aubagnac[,4],list(aubagnac[,1],aubagnac[,2]),mean,na.rm=TRUE)
se.s <- tapply(aubagnac[,3],list(aubagnac[,1],aubagnac[,2]),sem)
se.b <- tapply(aubagnac[,4],list(aubagnac[,1],aubagnac[,2]),sem)

# barplots
par(mfrow=c(3,1),las=1)
# day 6
me <- as.numeric(rbind(me.s[,1],me.b[,1]))
se <- as.numeric(rbind(se.s[,1],se.b[,1]))
barplot(me,width=1,space=c(0,0,rep(c(1,0),2)),xlab="Mouse Group",
        ylab="Amount of viral RNA (score)", ylim=c(0,4),xlim=c(-0.5,8.5),
        col=c("white","black"),main="6 days post-infection")
abline(h=0)
x <- c(-0.5,2.5,5.5,8.5)
segments(x,0,x,-0.1,xpd=TRUE)
text(c(1,4,7),-0.3,as.character(levels(aubagnac[,1])),xpd=TRUE)
legend(-0.5,4,c("Spinal cord","Brain"),pch=15,cex=1.15,
       col=c("white","black"))
legend(-0.5,4,c("",""),pch=0,bty="n",cex=1.15)
x <- c(0:1,3:4,6:7)+0.5
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)

# day 21
me <- as.numeric(rbind(me.s[,2],me.b[,2]))
se <- as.numeric(rbind(se.s[,2],se.b[,2]))
barplot(me,width=1,space=c(0,0,rep(c(1,0),2)),xlab="Mouse Group",
        ylab="Amount of viral RNA (score)", ylim=c(0,4),xlim=c(-0.5,8.5),
        col=c("white","black"),main="21 days post-infection")
abline(h=0)
x <- c(-0.5,2.5,5.5,8.5)
segments(x,0,x,-0.1,xpd=TRUE)
text(c(1,4,7),-0.3,as.character(levels(aubagnac[,1])),xpd=TRUE)
x <- c(0:1,3:4,6:7)+0.5
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)

# day 45
me <- me.s[,3];names(me) <- NULL
se <- se.s[,3]
barplot(me,width=1,space=c(0,1,1),xlab="Mouse Group",
        ylab="Amount of viral RNA (score)", ylim=c(0,4),xlim=c(-0.5,5.5),
        col="white",main="45 days post-infection")
abline(h=0)
x <- c(-0.5,1.5,3.5,5.5)
segments(x,0,x,-0.1,xpd=TRUE)
x <- c(0,2,4)+0.5
text(x,-0.3,as.character(levels(aubagnac[,1])),xpd=TRUE)
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)

Cell surface adhesion receptor expression

Description

Data on cell surface adhesion receptor expression in ATII cells (from rats) after 1, 4 and 7 days of culture.

Usage

data(berrios)

Format

A data frame with three columns: days in culture, receptor molecule, and light intensity (a correlate of receptor expression).

Rolf D. Hubmayr, Mayo Clinic and Foundation, Rochester, MN

References

Berrios, J. C., Schroeder, M. A. and Hubmayr, R. D. (2001) Mechanical properties of alveolar epithelial cells in culture. J. Appl. Physiol. 91, 65–73. (See Figure 2.)

See Also

sem

Examples

data(berrios)

# means and SEs
me <- tapply(berrios[,3], list(berrios[,2], berrios[,1]), mean, na.rm=TRUE)
se <- tapply(berrios[,3], list(berrios[,2], berrios[,1]), sem)
se <- se/me[,1]*100
me <- me/me[,1]*100
me <- as.numeric(t(me))[-6]
se <- as.numeric(t(se))[-6]

# barplot
par(las=1)
barplot(me, col=c("white","gray80","gray40","white","gray80"),
        names.arg=as.character(c(1,4,7,1,4)),
        ylim=c(0,250),xlim=c(0,5.5),width=1,space=c(0,0,0,0.5,0),
        ylab="Relative Light Intensity",xlab="Day")
abline(h=0)
x <- c(0.5,1.5,2.5,4,5)
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)
text(1.5,225,"ICAM-1",cex=1.3,font=2)
text(4.5,225,"RGD-Peptide",cex=1.3,font=2)

Ticks acquired while walking with sneakers or boots.

Description

Numbers of ticks acquired while walking with tick preventive (boots and tape) or nonpreventive (sneakers and minimal tape) footwear.

Usage

data(carroll1)

Format

A data frame with three columns: number of ticks and number of times (out of ten) that number was observed with sneakers and boots.

John F. Carroll, USDA

References

Carroll, J. F. and Kramer, M. (2001) Different activities and footwear influence exposure to host-seeking nymphs of Ixodes scapularis and Amblyomma americanum. J. Med. Entomol. 38, 596–600. (See Figure 1b.)

See Also

carroll2, carroll3

Examples

data(carroll1)
# barplot
barplot(as.numeric(t(carroll1[,-1])), space=c(0,0,1,0,1,0),
        col=rep(c("white","black"),3),ylab="Number of samples",
        xlab="Number of nymphs per sample",ylim=c(0,10),
        xlim=c(-0.5,8.5))
abline(h=0)
segments(c(1,4,7),0,c(1,4,7),-0.25,xpd=TRUE)
text(c(1,4,7),-0.7,c("0","1","2"),xpd=TRUE)
legend(5.5,10,c("sneakers","boots"),pch=15,cex=1.3,
       col=c("white","black"))
legend(5.5,10,c("",""),pch=0,bty="n",cex=1.3)

Ticks acquired while walking or crawling

Description

Numbers of ticks acquired while walking or crawling.

Usage

data(carroll2)

Format

A data frame with three columns: number of ticks and number of times (out of 50) that number was observed when walking and crawling.

John F. Carroll, USDA

References

Carroll, J. F. and Kramer, M. (2001) Different activities and footwear influence exposure to host-seeking nymphs of Ixodes scapularis and Amblyomma americanum. J. Med. Entomol. 38, 596–600. (See Figure 1a.)

See Also

carroll1, carroll3

Examples

data(carroll2)
# barplot
barplot(as.numeric(t(carroll2[,-1])), space=c(0,0,rep(c(1,0),7)),
        col=rep(c("white","black"),3),ylab="Number of samples",
        xlab="Number of nymphs per sample",ylim=c(0,40),
        xlim=c(-0.5,23.5))
abline(h=0)
segments((0:7)*3+1,0,(0:7)*3+1,-1,xpd=TRUE)
text((0:7)*3+1,-2.8,as.character(0:7),xpd=TRUE)
legend(15.5,40,c("walking","crawling"),pch=15,cex=1.3,
       col=c("white","black"))
legend(15.5,40,c("",""),pch=0,bty="n",cex=1.3)

Counts of ticks seeking gland substances

Description

Numbers of ticks going to a gland-substance-treated capillary tube versus an untreated tube.

Usage

data(carroll3)

Format

A data frame with five columns: sex of tick, deer leg (fore/hind), deer sex, and numbers of ticks going to treated and untreated tubes.

John F. Carroll, USDA

References

Carroll, J. F. (2001) Interdigital gland substances of white-tailed deer and the response of host-seeking ticks (acari: ixodidae). J. Med. Entomol. 38, 114–117. (See Table 1.)

See Also

carroll1, carroll2

Examples

data(carroll3)
# p-values for comparison of observed proportion to 50:50.
pval <- 1-pbinom(carroll3[,4],carroll3[,4]+carroll3[,5],0.5)

Humoral response to pertussis antigen

Description

Humoral response to pertussis antigen in vaccinated children and children with a history of pertussis infection.

Usage

data(esposito)

Format

A data frame with six columns: number of children that are PT, FHA, and PRN positive and negative.

References

Esposito, S., Agliardi, T., Giammanco, A., Faldella, G., Cascio, A., Bosis, S., Friscia, O., Clerici, M. and Principi, N. (2001) Long-term pertussis-specific immunity after primary vaccination with a combined diphtheria, tetanus, tricomponent acellular pertussis and hepatitis B vaccine in comparison with that after natural infection. Infection and Immunity 69, 4516–4520. (See Table 1.)

Examples

data(esposito)
# Fisher's exact tests
fisher.test(esposito[,1:2]) # PT
fisher.test(esposito[,3:4]) # FHA
fisher.test(esposito[,5:6]) # PRN

Number of mosquitoes re-captured

Description

Number of 13-day-old and 3-day-old recaptured near the site of release.

Usage

data(harrington)

Format

A data frame with two columns: number of mosquitoes re-captured and the total number released.

References

Harrington, L. C., Buonaccorsi, J. P., Edman, J. D., Costero, A., Kittayapong, P., Clark, G. G. and Scott, T. W. (2001) Analysis of survival of young and old Aedes aegypti (diptera: culicidae) from Puerto Rico and Thailand. J. Med. Entomol. 38, 537-547. (See Table 2.)

Examples

data(harrington)
x <- harrington
x[,2] <- x[,2]-x[,1]
# Fisher's exact tests
fisher.test(x)

Myocarditis in mice

Description

Data on myocarditis in mice that are infected with H3 or H310A1 viruses or left uninfected.

Usage

data(huber1)

Format

A data frame with seven columns: treatment, percent mycardium inflamed, virus titer (log10 PFU), total number of lymphoctyes (/10610^6), percent of CD4+ cells in spleen, percent of CD4+ cells that are IFN-γ\gamma+ and that are IL-4+.

Sally Huber, Department of Pathology, University of Vermont

References

Huber, S. A., Graveline, D., Born, W. K. and O'Brien, R. L. (2001) Cytokine production by Vγ\gamma+-T-cell subsets is an important factor determining CD4+-Th-cell phenotype and susceptibility of BALB/c mice to coxsackievirus B3-induced myocarditus. J. Virol. 75, 5860–5769. (See Table 1.)

See Also

huber2

Examples

data(huber1)

# means
means <- matrix(ncol=6,nrow=3)
for(i in 1:6)
  means[,i] <- tapply(huber1[,i+1],huber1[,1],mean,na.rm=TRUE)

# SDs
sds <- means
for(i in 1:6)
  sds[,i] <- tapply(huber1[,i+1],huber1[,1],sd,na.rm=TRUE)

dimnames(means) <- dimnames(sds) <-
    list(levels(huber1[,1]),colnames(huber1)[-1])

round(means,2)
round(sds,2)

Myocarditis in mice

Description

Data on myocarditis in antibody-treated mice that are further infected with H3 or H310A1 viruses or left uninfected.

Usage

data(huber2)

Format

A data frame with three columns: antibody treatment, infection status, and percent myocarditis.

Sally Huber, Department of Pathology, University of Vermont

References

Huber, S. A., Graveline, D., Born, W. K. and O'Brien, R. L. (2001) Cytokine production by Vγ\gamma+-T-cell subsets is an important factor determining CD4+-Th-cell phenotype and susceptibility of BALB/c mice to coxsackievirus B3-induced myocarditus. J. Virol. 75, 5860–5769. (See Figure 4.)

See Also

huber1

Examples

data(huber2)
means <- tapply(huber2[,3],list(huber2[,1],huber2[,2]),mean)
sds <- tapply(huber2[,3],list(huber2[,1],huber2[,2]),sd)

# barplot
x1 <- as.numeric(means)
x2 <- as.numeric(sds)
par(las=1)
barplot(x1,ylim=c(0,18),col=rep(c("white","black","gray70"),3),
        names.arg=NULL,xlim=c(0,11),width=1,space=c(0,0,0,1,0,0,1,0,0))
abline(h=0)
text(1.5,-1,"Uninfected",xpd=TRUE)
text(5.5,-1,"H3-Infected",xpd=TRUE)
text(9.5,-1,"H310A1-Infected",xpd=TRUE)
x <- c(0:2,4:6,8:10)+0.5
segments(x,x1,x,x1+x2,lwd=2)
segments(x-0.1,x1+x2,x+0.1,x1+x2,lwd=2)
legend(6.5,17,c("Hamster-IgG","Anti-Vg1","Anti-Vg4"),col=c("white","black","gray70"),
       pch=15,cex=1.3)
legend(6.5,17,c("","",""),pch=0,bty="n",cex=1.3)
u <- par("usr")
x <- c(u[1],3.5,7.5,u[2])
segments(x,0,x,-0.5,xpd=TRUE)

Numbers of crossovers in human

Description

Numbers of crossovers on each chromosome for each meiosis in eight CEPH families.

Usage

data(humanXO)

Format

A data frame with rows corresponding to meioses (there are 184 total). The first three columns indicate the family and individual identifiers, and whether the row corresponds to the male or female meiosis. The following columns give the number of crossovers on each of the 23 chromosomes and then the total number of crossovers, genome-wide.

Karl W Broman, [email protected]

References

Broman, K. W., Murray, J. C., Sheffield, V. C., White, R. L., Weber, J. L. (1998) Comprehensive human genetic maps: Individual and sex-specific variation in recombination. Am J Hum Genet 63, 861–869. (See Figure 3 and Table 2.)

See Also

mouseXO

Examples

data(humanXO)
# maternal
total <- humanXO$total[humanXO$Par=="ma"]
fam <- factor(humanXO$Fam[humanXO$Par=="ma"],levels=unique(humanXO$Fam))
x <- 9-as.numeric(fam)
plot(total,x+runif(length(x),-0.15,0.15),yaxt="n",
     xlab="Total no. crossovers",ylab="Family",
     main="Female meioses")
u <- par("usr")
segments(u[1],1:8,u[1]-diff(u[1:2])*0.02,1:8,xpd=TRUE)
text(u[1]-diff(u[1:2])*0.03,9-(1:8),as.character(levels(fam)),xpd=TRUE,adj=1)
abline(h=1:8,lty=3)

# male meioses
total <- humanXO$total[humanXO$Par=="pa"]
fam <- factor(humanXO$Fam[humanXO$Par=="pa"],levels=unique(humanXO$Fam))
x <- 9-as.numeric(fam)
plot(total,x+runif(length(x),-0.15,0.15),yaxt="n",
     xlab="Total no. crossovers",ylab="Family",
     main="Male meioses")
u <- par("usr")
segments(u[1],1:8,u[1]-diff(u[1:2])*0.02,1:8,xpd=TRUE)
text(u[1]-diff(u[1:2])*0.03,9-(1:8),as.character(levels(fam)),xpd=TRUE,adj=1)
abline(h=1:8,lty=3)

Luciferase activity

Description

Data on Luciferase activity in p53 +/+ and p53 -/- cells that are left untreated or in IFN, dsRNA, or SV medium.

Usage

data(hummer)

Format

A data frame with three columns: medium, p53 +/+ or -/-, and luceriferase activity.

B. A. Hassel, University of Maryland

References

Hummer, B. T., Li, X.-L. and Hassel, B. A. (2001) Role for p53 in gene induction by double-stranded RNA. J. Virol 75, 7774-7777. (See Figure 4.)

See Also

sem

Examples

data(hummer)
means <- tapply(hummer[,3],list(hummer[,2],hummer[,1]),mean)
sds <- tapply(hummer[,3],list(hummer[,2],hummer[,1]),sd)

# barplot
x1 <- as.numeric(means)
x2 <- as.numeric(sds)
par(las=1)
barplot(x1,ylim=c(0,125),col=rep(c("white","gray70"),4),
        names.arg=NULL,xlim=c(0,11),width=1,space=c(0,0,1,0,1,0,1,0))
abline(h=0)
text(c(1,4,7,10),-10,c("untrt","IFN","dsRNA","SV"),xpd=TRUE)
x <- c(0:1,3:4,6:7,9:10)+0.5
segments(x,x1,x,x1+x2,lwd=2)
segments(x-0.1,x1+x2,x+0.1,x1+x2,lwd=2)
u <- par("usr")
segments(c(u[1],2.5,5.5,8.5,u[2]),0,c(u[1],2.5,5.5,8.5,u[2]),-3,xpd=TRUE)
legend(0,120,c("p53 +/+", "p53 -/-"),col=c("white","gray70"),
       pch=15,cex=1.3)
legend(0,120,c("",""),pch=0,bty="n",cex=1.3)

Effect of immunization on the pneumococci infection in mice

Description

Number of mice colonized by pneumococci when challenged 2 weeks post-immunization, with several different immunogens (including a control), all without adjuvant.

Usage

data(malley1)

Format

A data frame with two columns: number colonized and total number.

References

Malley, R., Lipsitch, M., Stack, A., Saladino, R., Fleisher, G., Pelton, S., Thompson, C., Briles, D. and Anderson, P. (2001) Intranasal immunization with killed unencapsulated whole cells prevents colonization and invasive disease by capsulated pneumococci. Infection and Immunity 69:4870–4873. (See Table 1.)

See Also

malley2, malley3

Examples

data(malley1)
# p-values by Fisher's exact tests
p <- 1:4
for(i in 1:4) {
  x <- malley1[c(1,i+1),]
  x[,2] <- x[,2]-x[,1]
  p[i] <- fisher.test(x)$p.value
}
round(p,3)

Effect of immunization on the pneumococci infection in mice

Description

Number of mice colonized by pneumococci when challenged 2 weeks post-immunization, with adjuvant alone versus adjuvant with killed Rx1AL- immunogen.

Usage

data(malley2)

Format

A data frame with two columns: number colonized and total number.

References

Malley, R., Lipsitch, M., Stack, A., Saladino, R., Fleisher, G., Pelton, S., Thompson, C., Briles, D. and Anderson, P. (2001) Intranasal immunization with killed unencapsulated whole cells prevents colonization and invasive disease by capsulated pneumococci. Infection and Immunity 69:4870–4873. (See Table 1.)

See Also

malley1, malley3

Examples

data(malley2)
# Fisher's exact tests
x <- malley2
x[,2] <- x[,2]-x[,1]
fisher.test(x)

Effect of immunization on the pneumococci infection in rats

Description

Number of rats colonized by pneumococci post-immunization, with adjuvant alone versus adjuvant and killed Rx1AL- immunogen.

Usage

data(malley3)

Format

A data frame with four columns: replicate (A/B), number of ill rats, number of dead rats, and total number of rats.

References

Malley, R., Lipsitch, M., Stack, A., Saladino, R., Fleisher, G., Pelton, S., Thompson, C., Briles, D. and Anderson, P. (2001) Intranasal immunization with killed unencapsulated whole cells prevents colonization and invasive disease by capsulated pneumococci. Infection and Immunity 69:4870–4873. (See Table 2.)

See Also

malley1, malley2

Examples

data(malley3)
# p-values by Fisher's exact tests
p <- 1:4
# repl A; ill
x <- malley3[1:2,c(2,4)]
x[,2] <- x[,2]-x[,1]
p[1] <- fisher.test(x)$p.value
# repl A; dead
x <- malley3[1:2,c(3,4)]
x[,2] <- x[,2]-x[,1]
p[2] <- fisher.test(x)$p.value
# repl B; ill
x <- malley3[3:4,c(2,4)]
x[,2] <- x[,2]-x[,1]
p[3] <- fisher.test(x)$p.value
# repl B; dead
x <- malley3[3:4,c(3,4)]
x[,2] <- x[,2]-x[,1]
p[4] <- fisher.test(x)$p.value

RBC velocity and capillary diameter by capillaroscopy

Description

Estimated red blood cell velocity and capillary diameter at rest and during venous occlusion, obtained by capillaroscopy.

Usage

data(mathura1)

Format

A data frame with four columns: estimated RBC velocity at rest and during venous occlusion, followed by estimated capillary diameter at rest and during venous occlusion.

Can Ince, University of Amsterdam.

References

Mathura, K. R., Vollebregt, K. C., Boer, K., De Graaff, J. C., Ubbink, D. T. and Ince, C. (2001) Comparison of OPS imaging and conventional capillary microscopy to study the human microcirculation. J. Appl. Physiol. 91, 74–78. (See Figures 1 and 4.)

See Also

mathura2

Examples

data(mathura1)
data(mathura2)

par(las=1,mfrow=c(2,1))
boxplot(mathura1[,1],mathura1[,2],mathura2[,1],mathura2[,2],ylim=c(0,1.6),
        names=c("RBCVr","RBCVvo","RBCVr","RBCVvo"),ylab="RBC velocity (mm/s)")
abline(v=2.5,lty=3)
u <- par("usr")
text(c(1.5,3.5),u[4]+diff(u[3:4])*0.10,c("Capillaroscopy","OPS Imaging"),
     cex=1.3,xpd=TRUE)

boxplot(mathura1[,3],mathura1[,4],mathura2[,3],mathura2[,4],ylim=c(0,20),
        names=c("RBCVr","RBCVvo","RBCVr","RBCVvo"),
        ylab=expression(paste("diameter (", mu, "m)")))
abline(v=2.5,lty=3)
u <- par("usr")
text(c(1.5,3.5),u[4]+diff(u[3:4])*0.10,c("Capillaroscopy","OPS Imaging"),
     cex=1.3,xpd=TRUE)

RBC velocity and capillary diameter by OPS imaging

Description

Estimated red blood cell velocity and capillary diameter at rest and during venous occlusion, obtained by OPS imaging.

Usage

data(mathura2)

Format

A data frame with four columns: estimated RBC velocity at rest and during venous occlusion, followed by estimated capillary diameter at rest and during venous occlusion.

Can Ince, University of Amsterdam.

References

Mathura, K. R., Vollebregt, K. C., Boer, K., De Graaff, J. C., Ubbink, D. T. and Ince, C. (2001) Comparison of OPS imaging and conventional capillary microscopy to study the human microcirculation. J. Appl. Physiol. 91, 74–78. (See Figures 1 and 4.)

See Also

mathura1

Examples

data(mathura1)
data(mathura2)

par(las=1,mfrow=c(2,1))
boxplot(mathura1[,1],mathura1[,2],mathura2[,1],mathura2[,2],ylim=c(0,1.6),
        names=c("RBCVr","RBCVvo","RBCVr","RBCVvo"),ylab="RBC velocity (mm/s)")
abline(v=2.5,lty=3)
u <- par("usr")
text(c(1.5,3.5),u[4]+diff(u[3:4])*0.10,c("Capillaroscopy","OPS Imaging"),
     cex=1.3,xpd=TRUE)

boxplot(mathura1[,3],mathura1[,4],mathura2[,3],mathura2[,4],ylim=c(0,20),
        names=c("RBCVr","RBCVvo","RBCVr","RBCVvo"),
        ylab=expression(paste("diameter (", mu, "m)")))
abline(v=2.5,lty=3)
u <- par("usr")
text(c(1.5,3.5),u[4]+diff(u[3:4])*0.10,c("Capillaroscopy","OPS Imaging"),
     cex=1.3,xpd=TRUE)

Bacterial counts in mosquitoes

Description

Bacterial counts in the meconium and lumen of three species of adult mosquitoes.

Usage

data(moll1)

Format

A data frame with six columns: specimen number, species, sex, age, location, and bacterial count.

William Romoser, Ohio University

References

Moll, R. M., Romoser, W. S., Modrzakowski, M. C., Moncayo, A. C. and Lerdthusnee, K. (2001) Meconial peritrophic membranes and the fate of midgut bacteria during mosquito (diptera: culcidae) metamorphosis. J. Med. Entomol. 38, 29–32. (See Table 1.)

See Also

moll2

Examples

data(moll1)
per <- tapply(moll1[,6],list(moll1[,2],moll1[,5]),function(a) mean(a>0))
me <- tapply(moll1[,6],list(moll1[,2],moll1[,5]),mean)
se <- tapply(moll1[,6],list(moll1[,2],moll1[,5]),sem)

Bacterial counts in mosquitoes

Description

Bacterial counts at different developmental stages in three species of mosquitoes.

Usage

data(moll2)

Format

A data frame with four columns: species, developmental stage, specimen number, and bacterial count.

William Romoser, Ohio University

References

Moll, R. M., Romoser, W. S., Modrzakowski, M. C., Moncayo, A. C. and Lerdthusnee, K. (2001) Meconial peritrophic membranes and the fate of midgut bacteria during mosquito (diptera: culcidae) metamorphosis. J. Med. Entomol. 38, 29–32. (See Table 2.)

See Also

moll1

Examples

data(moll2)
me <- tapply(moll2[,4],list(moll2[,2],moll2[,1]),mean)
se <- tapply(moll2[,4],list(moll2[,2],moll2[,1]),sem)
mn <- tapply(moll2[,4],list(moll2[,2],moll2[,1]),min)
mx <- tapply(moll2[,4],list(moll2[,2],moll2[,1]),max)

Virus production

Description

Virus production in serum samples pre- and post-incubation with V3 peptide or sterile PBS.

Usage

data(montefiori)

Format

A data frame with three columns: sample identifier, bleed (pre/post), V3 peptide (no/yes), and virus production (in ng/ml).

David Montefiori, Duke University Medical Center

References

Montefiori, D. C., Safrit, J. T., Lydy, S. L., Barry, A. P., Bilska, M., Vo, H. T. T., Klein, M., Tartaglia, J., Robinson, H. L. and Rovinski, B. (2001) Induction of neutralizing antibodies and gag-specific cellular immune responses to an R5 primary isolate of Human Immunodeficiency Virus Type 1 in rhesus macaques. J. Virol. 75, 5879–5890. (See Figure 4.)

See Also

sem

Examples

data(montefiori)
me <- tapply(montefiori[,4],list(montefiori[,3],montefiori[,2],montefiori[,1]),mean)
se <- tapply(montefiori[,4],list(montefiori[,3],montefiori[,2],montefiori[,1]),sem)

# barplot
me <- as.numeric(me)
se <- as.numeric(se)
barplot(me, col=rep(c("black","gray80"),4), xlim=c(-0.5,11.5),space=c(0,0,1,0,1,0,1,0),
        names.arg=NULL,ylim=c(0,12),ylab="Virus production (ng/ml)")
abline(h=0)
legend(1.5,12,c("no V3 peptide","with V3 peptide"),pch=15,cex=1.15,
       col=c("black","gray80"))
legend(1.5,12,c("",""),pch=0,bty="n",cex=1.15)
x <- c(-0.5,2.5,5.5,8.5,11.5)
segments(x,0,x,-0.2,xpd=TRUE)
text(c(1,4,7,10),-0.6,c("RQj5 pre","RQj5 post","RYl5 pre","RYl5 post"),xpd=TRUE)
x <- c(0:1,3:4,6:7,9:10)+0.5
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)

Numbers of crossovers in the mouse

Description

Numbers of crossovers on each chromosome for each meiotic product from two inter-specific mouse backcrosses: (C57BL/6J x Mus spretus) x C57BL/6J and (C57BL/6J x SPRET/EiJ) x SPRET/EiJ. Note that recombination is occuring in the female in each cross.

Usage

data(mouseXO)

Format

A data frame with rows corresponding to meioses (there are 94 meioses for each backcross) and columns corresponding to the 20 chromosomes. There is also a column for the total number of crossovers, genome-wide, for each meiosis.

Karl W Broman, [email protected]

References

Broman, K. W., Rowe, L. R., Churchill, G. A. and Paigen, K. (2001) Crossover interference in the mouse. Genetics, in press.

See Also

humanXO

Examples

data(mouseXO)
total <- mouseXO[,ncol(mouseXO)]
cross <- rep(1:2,rep(94,2))
par(las=1)
boxplot(split(total,cross),names=c("BSB","BSS"),
        ylab="Total no. crossovers", xlab="Cross")
rug(total[cross==1]+runif(94,-0.1,0.1),side=2)
rug(total[cross==2]+runif(94,-0.1,0.1),side=4)

Hydrosalpinx formation

Description

Hydrosalpinx formation in three strains of mice when infected or not with Chlamydia trachomatis.

Usage

data(ramsey)

Format

A data frame with two columns: number of mice displaying hydrosalpinx formation, and total number of mice.

References

Ramsey, K. H., Miranpuri, G. S., Sigar, I. M., Ouellette, S. and Byrne, G. I. (2001) Chlamydia trachomatis persistence in the female mouse genital tract: Inducible nitric oxide synthase and infection outcome. Infection and Immunity 69, 5131-5137. (See Table 1.)

Examples

data(ramsey)
x <- ramsey
x[,2] <- x[,2]-x[,1]
# Fisher's exact tests
fisher.test(x[-3,])
fisher.test(x[-2,])

Percent apopototic cells

Description

Percent apoptotic cells in the HEK/CD4.403/CXCR4 cell line after coculture with CEM cells or 8.E5 cells.

Usage

data(roggero1)

Format

A data frame with two columns: type of cells in coculture and percent apopototic cells.

Martine Biard-Piechaczyk, Institut de Biologie, Montpellier, France

References

Roggero, R., Robert-Hebmann, V., Harrington, S., Roland, J., Vergne, L., Jaleco, S., Devaux, C. and Biard-Piechaczyk, M. (2001) J. Virol. 75, 7637-7650. (See Figure 1C.)

See Also

roggero2

Examples

data(roggero1)
data(roggero2)
me <- c(tapply(roggero1[,2],roggero1[,1],mean),
        tapply(roggero2[,2],roggero2[,1],mean))
se <- c(tapply(roggero1[,2],roggero1[,1],sem),
        tapply(roggero2[,2],roggero2[,1],sem))
par(las=1)
barplot(me,xlab="",ylab="Percent apoptotic cells",width=1,ylim=c(0,20),
        xlim=c(-0.5,5.5),space=c(0,0,1,0),col=rep(c("white","gray"),2))
abline(h=0)
abline(v=2.5,lty=3)
text(1,19,"HEK/CD4.403/CXCR4",cex=1.3,xpd=TRUE)
text(4,19,"A2.01/CD4.403",cex=1.3,xpd=TRUE)
x <- c(0,1,3,4)+0.5
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)

Percent apopototic cells

Description

Percent apoptotic cells in the A201/CD4.403 cell line after coculture with HEK cells or HEK.gp120 cells.

Usage

data(roggero2)

Format

A data frame with two columns: type of cells in coculture and percent apopototic cells.

Martine Biard-Piechaczyk, Institut de Biologie, Montpellier, France

References

Roggero, R., Robert-Hebmann, V., Harrington, S., Roland, J., Vergne, L., Jaleco, S., Devaux, C. and Biard-Piechaczyk, M. (2001) J. Virol. 75, 7637-7650. (See Figure 1C.)

See Also

roggero1

Examples

data(roggero1)
data(roggero2)
me <- c(tapply(roggero1[,2],roggero1[,1],mean),
        tapply(roggero2[,2],roggero2[,1],mean))
se <- c(tapply(roggero1[,2],roggero1[,1],sem),
        tapply(roggero2[,2],roggero2[,1],sem))
par(las=1)
barplot(me,xlab="",ylab="Percent apoptotic cells",width=1,ylim=c(0,20),
        xlim=c(-0.5,5.5),space=c(0,0,1,0),col=rep(c("white","gray"),2))
abline(h=0)
abline(v=2.5,lty=3)
text(1,19,"HEK/CD4.403/CXCR4",cex=1.3,xpd=TRUE)
text(4,19,"A2.01/CD4.403",cex=1.3,xpd=TRUE)
x <- c(0,1,3,4)+0.5
segments(x,me,x,me+se,lwd=2)
segments(x-0.1,me+se,x+0.1,me+se,lwd=2)

Quasispecies variation

Description

Quasispecies variation in CMV and TMV populations in different host species.

Usage

data(schneider)

Format

A data frame with six columns: virus type (CMV/TMV), host species, number of mutated clones, total number of clones, number of mutations, and total number of bases.

References

Schneider, W. L. and Roossinck, M. J. (2001) Genetic diversity in RNA virus quasispecies is controlled by host-virus interactions. J. Virol. 75, 6566-6571. (See Table 1.)

Examples

data(schneider)

Standard error of the mean

Description

Calculate the standard error of the mean (SEM) for a vector of numbers.

Usage

sem(x)

Arguments

x

A vector of numbers.

Details

The returned value is s/(n)s/\sqrt(n) where s is the sample standard deviation (SD) and n is the sample size. Missing values are discarded.

Value

The estimated standard error of the estimate of the mean of the population from which the numbers were drawn.

Author(s)

Karl W Broman, [email protected]

Examples

x <- rnorm(100,10,2)
mean(x)
sem(x)